@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2025 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -13,6 +13,7 @@ from lib.core.common import urldecode
 from lib.core.common import parseXmlFile
 from lib.core.data import kb
 from lib.core.data import paths
+from lib.core.settings import HEURISTIC_PAGE_SIZE_THRESHOLD
 from lib.core.threads import getCurrentThreadData
 
 class HTMLHandler(ContentHandler):
@@ -69,6 +70,8 @@ def htmlParser(page):
     >>> threadData.lastErrorPage = None
     """
 
+    page = page[:HEURISTIC_PAGE_SIZE_THRESHOLD]
+
     xmlfile = paths.ERRORS_XML
     handler = HTMLHandler(page)
     key = hash(page)
