@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2021 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2025 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -21,10 +21,9 @@ from plugins.generic.connector import Connector as GenericConnector
 
 class Connector(GenericConnector):
     """
-    Homepage: http://code.google.com/p/pymysql/
-    User guide: http://code.google.com/p/pymysql/
-    API: http://code.google.com/p/pymysql/
-    Debian package: <none>
+    Homepage: https://github.com/PyMySQL/PyMySQL
+    User guide: https://pymysql.readthedocs.io/en/latest/
+    Debian package: python3-pymysql
     License: MIT
 
     Possible connectors: http://wiki.python.org/moin/MySQL
