@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2025 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -26,6 +26,6 @@ class Syntax(GenericSyntax):
             if all(_ < 128 for _ in getOrds(value)):
                 return "0x%s" % getUnicode(binascii.hexlify(getBytes(value)))
             else:
-                return "CONVERT(0x%s USING utf8)" % getUnicode(binascii.hexlify(getBytes(value)))
+                return "CONVERT(0x%s USING utf8)" % getUnicode(binascii.hexlify(getBytes(value, "utf8")))
 
         return Syntax._escape(expression, quote, escaper)
